@@ -423,11 +423,16 @@ class SilverIngestionInsertOnlyService(BaseSilverIngestionServiceImpl):
             has_schema_changed (bool): Indicates if the schema has changed.
             target_columns_ordered (list[str]): The ordered list of target columns.
         """
-        if not has_schema_changed:
+        is_mlv_existing = (
+            self._spark.catalog.tableExists(self._mlv.table_path)
+            if not self._is_testing_mock else True
+        )
+        if not has_schema_changed and is_mlv_existing:
             logger.info("MLV: No schema change detected.")
             return
 
-        self._mlv.drop()
+        if is_mlv_existing:
+            self._mlv.drop()
         self._create_historized_mlv(target_columns_ordered)
 
     def _create_historized_mlv(self, target_columns_ordered: list[str]) -> None:
@@ -468,11 +473,15 @@ WITH cte_mlv AS (
 ), cte_mlv_final AS (
     SELECT
         *
-        ,IIF({self._row_hist_number_column} = 1 AND {self._row_delete_dts_column} IS NULL, 1, 0) AS {self._row_is_current_column}
+        ,CASE
+            WHEN {self._row_hist_number_column} = 1 AND {self._row_delete_dts_column} IS NULL THEN 1
+            ELSE 0
+        END AS {self._row_is_current_column}
+    FROM cte_mlv
 )
 SELECT
 {final_ordered_columns_str}
-FROM cte_mlv
+FROM cte_mlv_final
 """
 
     def _mlv_silver_columns_ordered_str(self, target_columns_ordered: list[str]) -> str:
